@@ -35,8 +35,7 @@ public:
 public:
     void initFSSupport() override;
 
-    QList<Device*> scanDevices(bool excludeReadOnly = false) override;
-    QList<Device*> scanDevices(const ScanFlags scanFlags) override;
+    QList<Device*> scanDevices(const ScanFlags scanFlags = {}) override;
     std::unique_ptr<CoreBackendDevice> openDevice(const Device& d) override;
     std::unique_ptr<CoreBackendDevice> openDeviceExclusive(const Device& d) override;
     bool closeDevice(std::unique_ptr<CoreBackendDevice> coreDevice) override;
